@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Moo;
 use strictures 2;
@@ -14,6 +14,7 @@ use Lingua::EN::Ngram;
 use List::Util qw( shuffle );
 use List::Util::WeightedChoice qw( choose_weighted );
 use MIDI::Simple;
+use Music::Gestalt;
 use Music::Note;
 use Music::Tempo;
 
@@ -121,6 +122,13 @@ has one_channel => (
 );
 
 
+has gestalt => (
+    is      => 'ro',
+    isa     => \&_invalid_boolean,
+    default => sub { 0 },
+);
+
+
 has score => (
     is       => 'rw',
     init_arg => undef,
@@ -205,11 +213,35 @@ sub process {
             # Save the number of times the phrase is repeated
             $self->notes->{$track_channel}{$num} = $phrase->{$p};
         }
+
+        $analysis .= $self->_gestalt_analysis( \@events )
+            if $self->gestalt;
     }
 
     return $analysis;
 }
 
+sub _gestalt_analysis {
+    my ( $self, $events ) = @_;
+
+    my $score_r = MIDI::Score::events_r_to_score_r( $events );
+    $score_r = MIDI::Score::sort_score_r($score_r);
+
+    my $g = Music::Gestalt->new( score => $score_r );
+
+    my $note = Music::Note->new( $g->PitchLowest, 'midinum' );
+    my $low  = $note->format('midi');
+    $note    = Music::Note->new( $g->PitchHighest, 'midinum' );
+    my $high = $note->format('midi');
+    $note    = Music::Note->new( $g->PitchMiddle, 'midinum' );
+    my $mid  = $note->format('midi');
+
+    my $gestalt = "\tRange: $low to $high\n"
+        . "\tSpan: $mid +/- " . $g->PitchRange . "\n";
+
+    return $gestalt;
+}
+
 
 sub populate {
     my ($self) = @_;
@@ -400,7 +432,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -410,6 +442,7 @@ version 0.07
     ngram_size   => 3,
     patches      => [qw( 68 69 70 71 72 73 )],
     random_patch => 1,
+    gestalt      => 1,
   );
   my $analysis = $mng->process;
   my $playback = $mng->populate;
@@ -484,6 +517,10 @@ Boolean.  Allow single occurrence ngrams.  Default: 0
 
 Boolean.  Accumulate phrases into a single list.  Default: 0
 
+=head2 gestalt
+
+Boolean.  Include pitch range in the analysis.
+
 =head2 score
 
 The MIDI score object.  Constructed at runtime.  Constructor argument if given
